Class: Zenweb::Binary
Overview
A file representing a binary. This file is not rendered in any way, and doesn’t have the usual dependencies because its content would not be modified to changes in config or the like.
Constant Summary
Constants inherited from Page
Instance Attribute Summary
Attributes inherited from Page
#parent, #path, #site, #subpages
Instance Method Summary collapse
Methods inherited from Page
#[], #all_subpages, #all_subpages_by_level, #analytics, #binary, #binary=, #body, #breadcrumbs, #change_frequency, #clean_url, #config, #content, #date_from_path, #date_str, #dated?, #dated_path?, #depends_on, #disqus, #disqus_counts, #erb, #extend_md, #filetype, #filetypes, #format_date, #gauges_analytics, #google_ad, #google_analytics, #html?, #include, #index?, #initialize, #inspect, #layout, #link_head, #link_html, #markdown, #meta, #method_missing, #no_index?, #parent_url, #render, #render_erb, #render_less, #render_md, renderers_re, #run_js_script, #series_page, #stale?, #stylesheet, #subrender, #tag_pages, #url, #url_dir, #url_path
Constructor Details
This class inherits a constructor from Zenweb::Page
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Zenweb::Page
Instance Method Details
#date ⇒ Object
509 |
# File 'lib/zenweb/page.rb', line 509 def date = File.stat(path).mtime |
#generate ⇒ Object
511 512 513 514 515 516 |
# File 'lib/zenweb/page.rb', line 511 def generate warn "Linking #{url_path}" verbose = Rake.application..trace ln path, url_path, verbose: verbose touch url_path, mtime: date, verbose: verbose end |
#wire ⇒ Object
518 519 520 521 522 523 524 525 526 |
# File 'lib/zenweb/page.rb', line 518 def wire file self.path directory url_dir file url_path => url_dir file url_path => path do self.generate end task :site => url_path end |